<?php

namespace Assetproject\Report\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetproject\Report\Interfaces\ReportRepositoryInterface;
use Assetproject\Report\Repositories\Presenter\ReportItemTransformer;

/**
 * Pubic API controller class.
 */
class ReportApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetproject\Report\Interfaces\ReportRepositoryInterface $report
     *
     * @return type
     */
    public function __construct(ReportRepositoryInterface $report)
    {
        $this->middleware('api');

        $this->repository = $report;
        parent::__construct();
    }

    /**
     * Show report's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $reports = $this->repository
            ->pushCriteria(new \Assetproject\Report\Repositories\Criteria\ReportPublicCriteria())
            ->setPresenter('\\Assetproject\\Report\\Repositories\\Presenter\\ReportListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $reports['code'] = 2000;
        return response()->json($reports)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show report.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $report = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($report)) {
            $report         = $this->itemPresenter($module, new ReportItemTransformer);
            $report['code'] = 2001;
            return response()->json($report)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
