<?php

namespace Assetproject\Report\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Assetproject\Report\Models\Report;

class ReportPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the report.
     *
     * @param User $user
     * @param Report $report
     *
     * @return bool
     */
    public function view(User $user, Report $report)
    {
        if ($user->canDo('report.report.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $report->user_id;
    }

    /**
     * Determine if the given user can create a report.
     *
     * @param User $user
     * @param Report $report
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('report.report.create');
    }

    /**
     * Determine if the given user can update the given report.
     *
     * @param User $user
     * @param Report $report
     *
     * @return bool
     */
    public function update(User $user, Report $report)
    {
        if ($user->canDo('report.report.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $report->user_id;
    }

    /**
     * Determine if the given user can delete the given report.
     *
     * @param User $user
     * @param Report $report
     *
     * @return bool
     */
    public function destroy(User $user, Report $report)
    {
        if ($user->canDo('report.report.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $report->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
